@@ -26,8 +26,9 @@ SOFTWARE.
 """
 
 from .client import Client
+from .exceptions import HTTPException
 
 METRIC = "C"
 IMPERIAL = "F"
 __version__ = "0.3.1"
-__all__ = ("Client", "METRIC", "IMPERIAL", "__version__")
\ No newline at end of file
+__all__ = ("Client", "METRIC", "IMPERIAL", "HTTPException", "__version__")
\ No newline at end of file
